# Automatically generated by pb2py
# fmt: off
from .. import protobuf as p

from .MoneroMultisigKLRki import MoneroMultisigKLRki
from .MoneroOutputEntry import MoneroOutputEntry

if __debug__:
    try:
        from typing import List
    except ImportError:
        List = None  # type: ignore


class MoneroTransactionSourceEntry(p.MessageType):

    def __init__(
        self,
        outputs: List[MoneroOutputEntry] = None,
        real_output: int = None,
        real_out_tx_key: bytes = None,
        real_out_additional_tx_keys: List[bytes] = None,
        real_output_in_tx_index: int = None,
        amount: int = None,
        rct: bool = None,
        mask: bytes = None,
        multisig_kLRki: MoneroMultisigKLRki = None,
    ) -> None:
        self.outputs = outputs if outputs is not None else []
        self.real_output = real_output
        self.real_out_tx_key = real_out_tx_key
        self.real_out_additional_tx_keys = real_out_additional_tx_keys if real_out_additional_tx_keys is not None else []
        self.real_output_in_tx_index = real_output_in_tx_index
        self.amount = amount
        self.rct = rct
        self.mask = mask
        self.multisig_kLRki = multisig_kLRki

    @classmethod
    def get_fields(cls):
        return {
            1: ('outputs', MoneroOutputEntry, p.FLAG_REPEATED),
            2: ('real_output', p.UVarintType, 0),
            3: ('real_out_tx_key', p.BytesType, 0),
            4: ('real_out_additional_tx_keys', p.BytesType, p.FLAG_REPEATED),
            5: ('real_output_in_tx_index', p.UVarintType, 0),
            6: ('amount', p.UVarintType, 0),
            7: ('rct', p.BoolType, 0),
            8: ('mask', p.BytesType, 0),
            9: ('multisig_kLRki', MoneroMultisigKLRki, 0),
        }



# Automatically generated by pb2py
# fmt: off
from .. import protobuf as p

if __debug__:
    try:
        from typing import List
    except ImportError:
        List = None  # type: ignore


class GetPublicKey(p.MessageType):
    MESSAGE_WIRE_TYPE = 11

    def __init__(
        self,
        address_n: List[int] = None,
        ecdsa_curve_name: str = None,
        show_display: bool = None,
        coin_name: str = None,
        script_type: int = None,
    ) -> None:
        self.address_n = address_n if address_n is not None else []
        self.ecdsa_curve_name = ecdsa_curve_name
        self.show_display = show_display
        self.coin_name = coin_name
        self.script_type = script_type

    @classmethod
    def get_fields(cls):
        return {
            1: ('address_n', p.UVarintType, p.FLAG_REPEATED),
            2: ('ecdsa_curve_name', p.UnicodeType, 0),
            3: ('show_display', p.BoolType, 0),
            4: ('coin_name', p.UnicodeType, 0),  # default=Bitcoin
            5: ('script_type', p.UVarintType, 0),  # default=SPENDADDRESS
        }



# Automatically generated by pb2py
# fmt: off
from .. import protobuf as p


class GetEntropy(p.MessageType):
    MESSAGE_WIRE_TYPE = 9

    def __init__(
        self,
        size: int = None,
    ) -> None:
        self.size = size

    @classmethod
    def get_fields(cls):
        return {
            1: ('size', p.UVarintType, 0),  # required
        }
